@@ -56,23 +56,26 @@ type dockerTarManifest struct {
 	LayerSources map[digest.Digest]descriptor.Descriptor `json:",omitempty"`
 }
 
-type tarFileHandler func(header *tar.Header, trd *tarReadData) error
-type tarReadData struct {
-	tr          *tar.Reader
-	name        string
-	handleAdded bool
-	handlers    map[string]tarFileHandler
-	links       map[string][]string
-	processed   map[string]bool
-	finish      []func() error
-	// data processed from various handlers
-	manifests           map[digest.Digest]manifest.Manifest
-	ociIndex            v1.Index
-	ociManifest         manifest.Manifest
-	dockerManifestFound bool
-	dockerManifestList  []dockerTarManifest
-	dockerManifest      schema2.Manifest
-}
+type (
+	tarFileHandler func(header *tar.Header, trd *tarReadData) error
+	tarReadData    struct {
+		tr          *tar.Reader
+		name        string
+		handleAdded bool
+		handlers    map[string]tarFileHandler
+		links       map[string][]string
+		processed   map[string]bool
+		finish      []func() error
+		// data processed from various handlers
+		manifests           map[digest.Digest]manifest.Manifest
+		ociIndex            v1.Index
+		ociManifest         manifest.Manifest
+		dockerManifestFound bool
+		dockerManifestList  []dockerTarManifest
+		dockerManifest      schema2.Manifest
+	}
+)
+
 type tarWriteData struct {
 	tw    *tar.Writer
 	dirs  map[string]bool
@@ -1063,7 +1066,7 @@ func (rc *RegClient) ImageExport(ctx context.Context, r ref.Ref, outStream io.Wr
 		tw:    tw,
 		dirs:  map[string]bool{},
 		files: map[string]bool{},
-		mode:  0644,
+		mode:  0o644,
 	}
 
 	// retrieve image manifest
@@ -1837,7 +1840,7 @@ func (td *tarWriteData) tarWriteHeader(filename string, size int64) error {
 					Typeflag:   tar.TypeDir,
 					Name:       dirJoin + "/",
 					Size:       0,
-					Mode:       td.mode | 0511,
+					Mode:       td.mode | 0o511,
 					ModTime:    td.timestamp,
 					AccessTime: td.timestamp,
 					ChangeTime: td.timestamp,
@@ -1859,7 +1862,7 @@ func (td *tarWriteData) tarWriteHeader(filename string, size int64) error {
 		Typeflag:   tar.TypeReg,
 		Name:       filename,
 		Size:       size,
-		Mode:       td.mode | 0400,
+		Mode:       td.mode | 0o400,
 		ModTime:    td.timestamp,
 		AccessTime: td.timestamp,
 		ChangeTime: td.timestamp,
