@@ -36,9 +36,11 @@ import (
 	"github.com/regclient/regclient/types/warning"
 )
 
-var defaultDelayInit, _ = time.ParseDuration("0.1s")
-var defaultDelayMax, _ = time.ParseDuration("30s")
-var warnRegexp = regexp.MustCompile(`^299\s+-\s+"([^"]+)"`)
+var (
+	defaultDelayInit, _ = time.ParseDuration("0.1s")
+	defaultDelayMax, _  = time.ParseDuration("30s")
+	warnRegexp          = regexp.MustCompile(`^299\s+-\s+"([^"]+)"`)
+)
 
 const (
 	DefaultRetryLimit = 5 // number of times a request will be retried
@@ -428,7 +430,6 @@ func (resp *Resp) next() error {
 			// send request
 			hc := h.getHTTPClient(req.Repository)
 			resp.resp, err = hc.Do(httpReq)
-
 			if err != nil {
 				c.slog.Debug("Request failed",
 					slog.String("URL", u.String()),
